@@ -53,7 +53,7 @@ if sys.version_info >= (3, 0):
         except UnicodeError:  # wrong encoding
             # detect_encoding returns utf-8 if no encoding specified
             msg = 'Wrong (%s) or no encoding specified' % encoding
-            util.reraise(exceptions.AstroidBuildingException(msg))
+            raise exceptions.AstroidBuildingException(msg)
         return stream, encoding, data
 
 else:
@@ -125,10 +125,11 @@ class AstroidBuilder(raw_building.InspectBuilder):
             stream, encoding, data = open_source_file(path)
         except IOError as exc:
             msg = 'Unable to load file %r (%s)' % (path, exc)
-            util.reraise(exceptions.AstroidBuildingException(msg))
-        except (SyntaxError, LookupError) as exc:
-            # Python 3 encoding specification error or unknown encoding
-            util.reraise(exceptions.AstroidBuildingException(*exc.args))
+            raise exceptions.AstroidBuildingException(msg)
+        except SyntaxError as exc:  # py3k encoding specification error
+            raise exceptions.AstroidBuildingException(exc)
+        except LookupError as exc:  # unknown encoding
+            raise exceptions.AstroidBuildingException(exc)
         with stream:
             # get module name if necessary
             if modname is None:
@@ -143,7 +144,7 @@ class AstroidBuilder(raw_building.InspectBuilder):
     def string_build(self, data, modname='', path=None):
         """Build astroid from source code string."""
         module = self._data_build(data, modname, path)
-        module.file_bytes = data.encode('utf-8')
+        module.source_code = data.encode('utf-8')
         return self._post_build(module, 'utf-8')
 
     def _post_build(self, module, encoding):
@@ -154,7 +155,7 @@ class AstroidBuilder(raw_building.InspectBuilder):
         for from_node in module._import_from_nodes:
             if from_node.modname == '__future__':
                 for symbol, _ in from_node.names:
-                    module.future_imports.add(symbol)
+                    module._future_imports.add(symbol)
             self.add_from_names_to_locals(from_node)
         # handle delayed assattr nodes
         for delayed in module._delayed_assattr:
@@ -169,13 +170,8 @@ class AstroidBuilder(raw_building.InspectBuilder):
         """Build tree node from data and add some informations"""
         try:
             node = _parse(data + '\n')
-        except (TypeError, ValueError) as exc:
-            util.reraise(exceptions.AstroidBuildingException(*exc.args))
-        except SyntaxError as exc:
-            # Pass the entire exception object to AstroidBuildingException,
-            # since pylint uses this as an introspection method,
-            # in order to find what error happened.
-            util.reraise(exceptions.AstroidBuildingException(exc))
+        except (TypeError, ValueError, SyntaxError) as exc:
+            raise exceptions.AstroidBuildingException(exc)
         if path is not None:
             node_file = os.path.abspath(path)
         else:
@@ -206,12 +202,12 @@ class AstroidBuilder(raw_building.InspectBuilder):
                     imported = node.do_import_module()
                 except exceptions.InferenceError:
                     continue
-                for name in imported.wildcard_import_names():
+                for name in imported._public_names():
                     node.parent.set_local(name, node)
-                    sort_locals(node.parent.scope().locals[name])
+                    sort_locals(node.parent.scope()._locals[name])
             else:
                 node.parent.set_local(asname or name, node)
-                sort_locals(node.parent.scope().locals[asname or name])
+                sort_locals(node.parent.scope()._locals[asname or name])
 
     def delayed_assattr(self, node):
         """Visit a AssAttr node
@@ -226,15 +222,15 @@ class AstroidBuilder(raw_building.InspectBuilder):
                 try:
                     if inferred.__class__ is bases.Instance:
                         inferred = inferred._proxied
-                        iattrs = inferred.instance_attrs
+                        iattrs = inferred._instance_attrs
                     elif isinstance(inferred, bases.Instance):
                         # Const, Tuple, ... we may be wrong, may be not, but
                         # anyway we don't want to pollute builtin's namespace
                         continue
                     elif inferred.is_function:
-                        iattrs = inferred.instance_attrs
+                        iattrs = inferred._instance_attrs
                     else:
-                        iattrs = inferred.locals
+                        iattrs = inferred._locals
                 except AttributeError:
                     # XXX log error
                     continue
